# NOT RUN {
sample_sentiment <- analyze_sentiment(text_body = "Google, headquartered in Mountain View, unveiled
the new Android phone at the Consumer Electronic Show.
Sundar Pichai said in his keynote that users love
their new Android phones.",
flatten = TRUE)
sample_sentiment$documentSentiment
sample_sentiment$language
# }
# NOT RUN {
# }
Run the code above in your browser using DataLab