Learn R Programming

googlenlp (version 0.2.0)

configure_googlenlp: Configure your computer or a server to connect to the Google Cloud Natural Language API via R functions

Description

Creates variables in your .Renviron file for use by other googlenlp functions. This will edit your .Renviron file only if you call this function directly. If you prefer not to change your .Renviron file, use the set_api_key function instead.

Usage

configure_googlenlp()

Arguments

Value

None

Examples

Run this code
# NOT RUN {
configure_googlenlp()
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab