# NOT RUN {
sample_entities <- analyze_entities(text_body = "Google, headquartered in Mountain View, unveiled
the new Android phone at the Consumer Electronic Show.
Sundar Pichai said in his keynote that users love
their new Android phones.",
flatten = TRUE)
sample_entities$entities
sample_entities$language
# }
# NOT RUN {
# }
Run the code above in your browser using DataLab